@@ -22,7 +22,7 @@ sub conway {
     $args->{interval} ||= 200;
 
     if ($args->{wechsler} and not $NO_WECHSLER) {
-        my $wechsler = Encode::Wechsler->new( pad => 1 );
+        my $wechsler = Encode::Wechsler->new( pad => defined $args->{pad} ? $args->{pad} : 1 );
         my @grid;
         eval { @grid = $wechsler->decode( $args->{wechsler} ) };
         if ($@) {
@@ -252,6 +252,14 @@ with any valid Wechsler Code:
 
   conway( wechsler => 'xp3_0ggmligkcz32w46' )
 
+Some codes require additional padding in order to sustain properly.
+
+  conway( wechsler => 'xp30_ccx8k2s3zy3103y531e8', pad => 2 )
+
+Padding defaults to 1, so you may turn it off if you don't need it:
+
+  conway( wechsler => 'xp2_25a4owo4a52zy01221', pad => 0 )
+
 If you have L<Color::Spectrum> installed then you can activate a fading effect like so:
 
   conway( on => '#FF0000', off => '#999999', fade => 1 )
